Class: Decoding::Decoders::Pass

Inherits:
Decoding::Decoder show all
Defined in:
lib/decoding/decoders/pass.rb

Overview

Decoder that returns the original value as-is. You are not likely to need this that often, as it kind of defeats the point of decoding -- but it might be useful to inspect the original input value for logging or debugging purposes.

Instance Method Summary collapse

Methods inherited from Decoding::Decoder

#failure, #to_decoder

Instance Method Details

#call(value) ⇒ Object



10
# File 'lib/decoding/decoders/pass.rb', line 10

def call(value) = ok(value)