Exception: Decoding::Error
- Inherits:
-
StandardError
- Object
- StandardError
- Decoding::Error
- Defined in:
- lib/decoding/error.rb
Overview
Base class for all errors raised by this library.
Base class for all errors raised by this library.